@@ -289,7 +289,7 @@ class Spec:
                             'type': 'object',
                             'title': credential.title,
                             'subtitle': credential.title,
-                            'category': credential.category,
+                            'category': int(credential.category),
                             'properties': {
                                 'vaultId': {
                                     'type': 'string'
@@ -301,7 +301,7 @@ class Spec:
                         }
 
                         name = Spec.lower_first_letter(_credential['key'])
-                        pUISchema[name] = {'ui:field', 'credentials'}
+                        pUISchema[name] = {'ui:field': 'credentials'}
                         formData[name] = {
                             'vaultId': '_',
                             'itemId': '_'
@@ -406,7 +406,7 @@ class Spec:
         fields = cls().cls().__dict__
         for key in fields.keys():
             val = fields[key]
-            if isinstance(val, Credentials) or (isinstance(val, Variable) and not isinstance(val, InVariable) and not isinstance(val, OutVariable) and not isinstance(val, OptVariable) and val.option):
+            if isinstance(val, Variable) and not isinstance(val, InVariable) and not isinstance(val, OutVariable) and not isinstance(val, OptVariable) and val.option:
                 options.append({'key': key, 'val': val})
 
         return options
